@@ -1,6 +1,10 @@
 #' Set species interaction matrix
 #'
-#' @section Setting interactions:
+#' @section Setting interaction matrix:
+#' 
+#' You do not need to specify an interaction matrix. If you do not, then the
+#' predator-prey interactions are purely determined by the size of predator
+#' and prey and totally independent of the species of predator and prey.
 #' 
 #' The interaction matrix \eqn{\theta_{ij}} describes the interaction of each
 #' pair of species in the model. This can be viewed as a proxy for spatial
@@ -20,8 +24,7 @@
 #' interactions are determined entirely by size-preference.
 #' 
 #' This function checks that the supplied interaction matrix is valid and then
-#' stores it in the `interaction` slot of the params object before returning
-#' that object.
+#' stores it in the `interaction` slot of the `params` object.
 #'
 #' The order of the columns and rows of the `interaction` argument should be the
 #' same as the order in the species params data frame in the `params` object. If
@@ -39,20 +42,15 @@
 #'   species x prey species). Entries should be numbers between 0 and 1. By
 #'   default all entries are 1. See "Setting interactions" section below.
 #'
-#' @return MizerParams object with updated interaction matrix. Because of the
-#'   way the R language works, `setInteraction()` does not make the changes to
-#'   the params object that you pass to it but instead returns a new params
-#'   object. So to affect the change you call the function in the form
-#'   `params <- setInteraction(params, ...)`.
+#' @return `setInteraction`: A MizerParams object with updated interaction matrix
 #' @export
 #' @family functions for setting parameters
 #' @examples
-#' \dontrun{
-#' params <- newTraitParams()
-#' interaction <- getInteraction(params)
-#' interaction[1, 3] <- 0
-#' params <- setInteraction(params, interaction)
-#' }
+#' params <- newTraitParams(no_sp = 3)
+#' inter <- getInteraction(params)
+#' inter[1, 2:3] <- 0
+#' params <- setInteraction(params, interaction = inter)
+#' getInteraction(params)
 setInteraction <- function(params,
                            interaction = NULL) {
     assert_that(is(params, "MizerParams"))
@@ -105,10 +103,13 @@ setInteraction <- function(params,
     }
     params@species_params$interaction_resource <- species_params$interaction_resource
     
+    params@time_modified <- lubridate::now()
     return(params)
 }
 
 #' @rdname setInteraction
+#' @return `getInteraction()`: The interaction matrix (predator species x prey
+#'   species)
 #' @export
 getInteraction <- function(params) {
     params@interaction
