@@ -181,6 +181,7 @@ projectToSteady <- function(params,
         sim@effort <- sim@effort[sel, , drop = FALSE]
         return(sim)
     } else {
+        params@time_modified <- lubridate::now()
         return(params)
     }
 }
@@ -188,9 +189,9 @@ projectToSteady <- function(params,
 #' Set initial values to a steady state for the model
 #'
 #' The steady state is found by running the dynamics while keeping reproduction
-#' and other components constant until the size spectra no longer change (or
-#' until time `t_max` is reached, if earlier). Then the reproductive efficiencies
-#' are set to the values that give the level of reproduction observed in that
+#' and other components constant until the size spectra no longer change much (or
+#' until time `t_max` is reached, if earlier). Then the reproduction parameters
+#' are set to values that give the level of reproduction observed in that
 #' steady state.
 #'
 #' @param params A \linkS4class{MizerParams} object
@@ -205,6 +206,11 @@ projectToSteady <- function(params,
 #' @param return_sim If TRUE, the function returns the MizerSim object holding
 #'   the result of the simulation run. If FALSE (default) the function returns
 #'   a MizerParams object with the "initial" slots set to the steady state.
+#' @param preserve `r lifecycle::badge("experimental")`
+#'   Specifies whether the `reproduction_level` should be preserved (default)
+#'   or the maximum reproduction rate `R_max` or the reproductive
+#'   efficiency `erepro`. See [setBevertonHolt()] for an explanation
+#'   of the `reproduction_level`.
 #' @param progress_bar A shiny progress object to implement a progress bar in a
 #'   shiny app. Default FALSE.
 #' @export
@@ -216,9 +222,16 @@ projectToSteady <- function(params,
 #' plotSpectra(params)
 #' }
 steady <- function(params, t_max = 100, t_per = 1.5, dt = 0.1,
-                   tol = 0.1 * dt, return_sim = FALSE, progress_bar = TRUE) {
+                   tol = 0.1 * dt, return_sim = FALSE, 
+                   preserve = c("reproduction_level", "erepro", "R_max"),
+                   progress_bar = TRUE) {
     params <- validParams(params)
     
+    preserve <- match.arg(preserve)
+    old_reproduction_level <- getReproductionLevel(params)
+    old_R_max <- params@species_params$R_max
+    old_erepro <- params@species_params$erepro
+    
     # Force the reproduction to stay at the current level
     params@species_params$constant_reproduction <- getRDD(params)
     old_rdd_fun <- params@rates_funcs$RDD
@@ -246,69 +259,28 @@ steady <- function(params, t_max = 100, t_per = 1.5, dt = 0.1,
     # Restore original RDD and other dynamics
     params@rates_funcs$RDD <- old_rdd_fun
     params@other_dynamics <- old_other_dynamics
+    params@species_params$constant_reproduction <- NULL
     
-    # Retune the values of erepro so that we get the correct level of
-    # reproduction
-    params <- retune_erepro(params)
+    if (preserve == "reproduction_level") {
+        params <- setBevertonHolt(params, 
+                                  reproduction_level = old_reproduction_level)
+    } else if (preserve == "R_max") {
+        params <- setBevertonHolt(params, 
+                                  R_max = old_R_max)
+    } else {
+        params <- setBevertonHolt(params, erepro = old_erepro)
+    }
     
     if (return_sim) {
         object@params <- params
         return(object)
     } else {
+        params@time_modified <- lubridate::now()
         return(params)
     }
 }
 
 
-#' Retune reproduction efficiency to maintain initial egg abundances
-#'
-#' Sets the reproductive efficiency for all species so that the rate of egg
-#' production exactly compensates for the loss from the first size class due
-#' to growth and mortality. 
-#' 
-#' Currently works only if the model uses either Beverton-Holt density
-#' dependent reproduction or density-independent reproduction.
-#'
-#' @inheritParams steady
-#' @inheritParams valid_species_arg
-#' @return A MizerParams object with updated values for the `erepro` column
-#'   in the `species_params` data frame.
-#' @export
-#' @concept helper
-retune_erepro <- function(params, species = species_params(params)$species) {
-    assert_that(is(params, "MizerParams"))
-    species <- valid_species_arg(params, species, return.logical = TRUE)
-    if (sum(species) == 0) return(params)
-
-    mumu <- getMort(params)
-    gg <- getEGrowth(params)
-    rdi <- getRDI(params)
-    if (any(rdi == 0)) {
-        stop("Some species have no reproduction.")
-    }
-    rdd_new <- getRDD(params)
-    for (i in seq_len(nrow(params@species_params))[species]) {
-        gg0 <- gg[i, params@w_min_idx[i]]
-        mumu0 <- mumu[i, params@w_min_idx[i]]
-        DW <- params@dw[params@w_min_idx[i]]
-        n0 <- params@initial_n[i, params@w_min_idx[i]]
-        rdd_new[i] <- n0 * (gg0 + DW * mumu0)
-    }
-    if (params@rates_funcs$RDD == "BevertonHoltRDD") {
-        params@species_params$R_max[species] <- 4 * rdd_new[species]
-        rdi_new <- rdd_new / (1 - rdd_new / params@species_params$R_max)
-        params@species_params$erepro <- params@species_params$erepro *
-            rdi_new / rdi
-    } else if (params@rates_funcs$RDD == "noRDD") {
-        params@species_params$erepro <- rdd_new / rdi
-    } else {
-        stop("Currently mizer can no retune the reproduction when the model is",
-             " using ", params@rates_funcs$RDD)
-    }
-    params
-}
-
-
 #' Helper function to keep other components constant
 #' 
 #' @param params MizerParams object
@@ -324,8 +296,7 @@ constant_other <- function(params, n_other, component, ...) {
 #' Helper function to assure validity of species argument
 #' 
 #' If the species argument contains invalid species, then these are
-#' ignored but a warning is issued. If non of the species is valid, then
-#' an error is produced.
+#' ignored but a warning is issued.
 #' 
 #' @param object A MizerSim or MizerParams object from which the species
 #'   should be selected.
@@ -350,7 +321,7 @@ valid_species_arg <- function(object, species = NULL, return.logical = FALSE) {
     } else {
         stop("The first argument must be a MizerSim or MizerParams object.")
     }
-    assert_that(is.logical(return.logical))
+    assert_that(is.flag(return.logical))
     all_species <- dimnames(params@initial_n)$sp
     no_sp <- nrow(params@species_params)
     # Set species if missing to list of all non-background species
@@ -379,13 +350,10 @@ valid_species_arg <- function(object, species = NULL, return.logical = FALSE) {
                     "integers 1 to ", no_sp)
         }
         species.logical <- 1:no_sp %in% species
-        if (sum(species.logical) == 0) {
-            stop("None of the numbers in the species argument are valid species indices.")
-        }
         if (return.logical) {
             return(species.logical)
         }
-        return(all_species[species])
+        return(all_species[species[species %in% (1:no_sp)]])
     }
     invalid <- setdiff(species, all_species)
     if (length(invalid) > 0) {
@@ -393,9 +361,6 @@ valid_species_arg <- function(object, species = NULL, return.logical = FALSE) {
                 toString(invalid))
     }
     species <- intersect(species, all_species)
-    if (length(species) == 0) {
-        stop("The species argument matches none of the species in the params object")
-    }
     if (return.logical) {
         return(all_species %in% species)
     }
