@@ -102,9 +102,8 @@ getDiet <- function(params,
     # object@w_full[idx_sp] = object@w
     idx_sp <- (no_w_full - no_w + 1):no_w_full
     
-    # If the feeding kernel does not have a fixed predator/prey mass ratio
-    # then the integral is not a convolution integral and we can not use fft.
-    if (length(params@ft_pred_kernel_e) == 1) {
+    # If the user has set a custom kernel we can not use fft.
+    if (!is.null(comment(params@pred_kernel))) {
         # pred_kernel is predator species x predator size x prey size
         # We want to multiply this by the prey abundance, which is
         # prey species by prey size, sum over prey size. We use matrix
@@ -330,28 +329,25 @@ getGrowthCurves <- function(object,
                             percentage = FALSE) {
     if (is(object, "MizerSim")) {
         params <- object@params
-        t <- dim(object@n)[1]
-        n <- object@n[t, , ]
-        n_pp <- object@n_pp[t, ]
+        params <- setInitialValues(params, object)
     } else if (is(object, "MizerParams")) {
         params <- validParams(object)
-        n <- object@initial_n
-        n_pp <- object@initial_n_pp
     } else {
         stop("The first argument to `getGrowthCurves()` must be a ",
              "MizerParams or a MizerSim object.")
     }
     species <- valid_species_arg(params, species)
     # reorder list of species to coincide with order in params
-    idx <- which(dimnames(n)$sp %in% species)
-    species <- dimnames(n)$sp[idx]
+    idx <- which(params@species_params$species %in% species)
+    species <- params@species_params$species[idx]
     age <- seq(0, max_age, length.out = 50)
     ws <- array(dim = c(length(species), length(age)),
                 dimnames = list(Species = species, Age = age))
-    g <- getEGrowth(params, n, n_pp)
+    g <- getEGrowth(params)
     for (j in seq_along(species)) {
         i <- idx[j]
-        g_fn <- stats::approxfun(params@w, g[i, ])
+        g_fn <- stats::approxfun(c(params@w, params@species_params$w_inf[[i]]),
+                                 c(g[i, ], 0))
         myodefun <- function(t, state, parameters) {
             return(list(g_fn(state)))
         }
@@ -368,7 +364,8 @@ getGrowthCurves <- function(object,
 #' 
 #' Helper function that returns an array (species x size) of boolean values
 #' indicating whether that size bin is within the size limits specified by the
-#' arguments.
+#' arguments. Either the size limits can be the same for all species or they
+#' can be specified as vectors with one value for each species in the model.
 #' 
 #' @param params MizerParams object
 #' @param min_w Smallest weight in size range. Defaults to smallest weight in
@@ -391,8 +388,9 @@ getGrowthCurves <- function(object,
 #' \deqn{w = a l^b.}
 #' 
 #' It is possible to mix length and weight constraints, e.g. by supplying a
-#' minimum weight and a maximum length. The default values are the minimum and
-#' maximum weights of the spectrum, i.e. the full range of the size spectrum is
+#' minimum weight and a maximum length, but this must be done the same for
+#' all species. The default values are the minimum and
+#' maximum weights of the spectrum, i.e., the full range of the size spectrum is
 #' used.
 #' @export
 #' @concept helper
@@ -400,20 +398,41 @@ get_size_range_array <- function(params, min_w = min(params@w),
                                  max_w = max(params@w), 
                                  min_l = NULL, max_l = NULL, ...) {
     no_sp <- nrow(params@species_params)
-    if (!is.null(min_l) | !is.null(max_l))
-        if (any(!c("a", "b") %in% names(params@species_params)))
+    if (!is.null(min_l) | !is.null(max_l)) {
+        if (any(!c("a", "b") %in% names(params@species_params))) {
             stop("species_params slot must have columns 'a' and 'b' for ",
                  "length-weight conversion")
-    if (!is.null(min_l))
+        }
+        if (anyNA(params@species_params[["a"]]) ||
+            anyNA(params@species_params[["a"]])) {
+            stop("There must be no NAs in the species_params columns 'a' and 'b'.")
+        }
+    }
+    if (!is.null(min_l)) {
+        if (length(min_l) != 1 && length(min_l) != no_sp) {
+            stop("min_l must be a single number or a vector with one value for each species.")
+        }
         min_w <- params@species_params[["a"]] * 
             min_l ^ params@species_params[["b"]]
-    else min_w <- rep(min_w, no_sp)
-    if (!is.null(max_l))
+    }
+    if (!is.null(max_l)) {
+        if (length(max_l) != 1 && length(max_l) != no_sp) {
+            stop("max_l must be a single number or a vector with one value for each species.")
+        }
         max_w <- params@species_params[["a"]] *
             max_l ^ params@species_params[["b"]]
-    else max_w <- rep(max_w, no_sp)
-    if (!all(min_w < max_w))
-        stop("min_w must be less than max_w")
+    }
+    if (length(min_w) == 1) {
+        min_w <- rep(min_w, no_sp)
+    }
+    if (length(max_w) == 1) {
+        max_w <- rep(max_w, no_sp)
+    }
+    if (length(min_w) != no_sp || length(max_w) != no_sp) {
+        stop("min_w and max_w must be a single number of a vector with one
+             value for each species.")
+    }
+    if (!all(min_w < max_w)) stop("min_w must be less than max_w")
     min_n <- plyr::aaply(min_w, 1, function(x) params@w >= x, .drop = FALSE)
     max_n <- plyr::aaply(max_w, 1, function(x) params@w <= x, .drop = FALSE)
     size_n <- min_n & max_n
