@@ -1,12 +1,11 @@
-params <- NS_params
-
 test_that("We can set and get resource parameters", {
+  params <- NS_params
   rp <- resource_params(params)
   expect_identical(rp, params@resource_params)
   # Check that when called without parameters it leaves the params untouched
   # using expect_equal instead of expect_identical because the latter failed
   # on win_builder
-  expect_equal(params, setResource(params))
+  expect_unchanged(params, setResource(params))
   # Create example parameters
   resource_rate <- params@w_full
   comment(resource_rate) <- "resource_rate"
@@ -61,33 +60,91 @@ test_that("We can set and get resource parameters", {
                    resource_capacity[params@w_full <= w_pp_cutoff])
   # resource_params<- sets rates correctly
   resource_params(NS_params) <- resource_params(params)
-  expect_identical(NS_params, params)
+  expect_unchanged(NS_params, params)
 })
 
-test_that("setResource sets comments correctly", {
-  rate <- getResourceRate(params)
-  capacity <- getResourceCapacity(params)
-  # The comment arguments are ignored when the values are already commented
-  comment(rate) <- "testr"
-  comment(capacity) <- "testc"
-  params <- setResource(params, resource_rate = rate,
-                        comment_rate = "overwriter",
-                        resource_capacity = capacity,
-                        comment_capacity = "overwritec")
-  expect_identical(comment(params@rr_pp), "testr")
-  expect_identical(comment(params@cc_pp), "testc")
-  # But otherwise the comment arguments are stored correctly.
-  comment(rate) <- NULL
-  comment(capacity) <- NULL
-  params <- setResource(params, resource_rate = rate,
-                        comment_rate = "overwriter",
-                        resource_capacity = capacity,
-                        comment_capacity = "overwritec")
-  expect_identical(comment(params@rr_pp), "overwriter")
-  expect_identical(comment(params@cc_pp), "overwritec")
+test_that("Comment works on resource_rate", {
+  params <- NS_params
+  # if no comment, it is set automatically
+  resource_rate <- params@rr_pp
+  params <- setResource(params, resource_rate = resource_rate)
+  expect_identical(comment(params@rr_pp), "set manually")
+  
+  # comment is stored
+  comment(resource_rate) <- "test"
+  params <- setResource(params, resource_rate = resource_rate)
+  expect_identical(comment(params@rr_pp), "test")
+  
+  # if no comment, previous comment is kept
+  comment(resource_rate) <- NULL
+  params <- setResource(params, resource_rate = resource_rate)
+  expect_identical(comment(params@rr_pp), "test")
+  
+  # no message when nothing changes
+  expect_message(setResource(params), NA)
+  # but message when a change is not stored due to comment
+  params@resource_params$r_pp <- 1
+  expect_message(setResource(params),  "has been commented")
+  # Can reset
+  p <- setResource(params, reset = TRUE)
+  expect_equal(p@rr_pp[1], 
+               params@w_full[1] ^ (params@resource_params$n - 1),
+               check.attributes = FALSE)
+  expect_warning(setResource(params, resource_rate = resource_rate,
+                                  reset = TRUE),
+                 "Because you set `reset = TRUE`, the")
+})
+
+test_that("Comment works on resource_capacity", {
+  params <- setResource(NS_params)
+  # if no comment, it is set automatically
+  resource_capacity <- params@cc_pp
+  params <- setResource(params, resource_capacity = resource_capacity)
+  expect_identical(comment(params@cc_pp), "set manually")
+  
+  # comment is stored
+  comment(resource_capacity) <- "test"
+  params <- setResource(params, resource_capacity = resource_capacity)
+  expect_identical(comment(params@cc_pp), "test")
+  
+  # if no comment, previous comment is kept
+  comment(resource_capacity) <- NULL
+  params <- setResource(params, resource_capacity = resource_capacity)
+  expect_identical(comment(params@cc_pp), "test")
+  
+  # no message when nothing changes
+  expect_message(setResource(params), NA)
+  # but message when a change is not stored due to comment
+  params@resource_params$kappa <- 1
+  expect_message(setResource(params),  "has been commented")
+  # Can reset
+  p <- setResource(params, reset = TRUE)
+  expect_equal(p@cc_pp[1], 
+               params@w_full[1] ^ (-params@resource_params$lambda),
+               check.attributes = FALSE)
+  expect_warning(setResource(params, resource_capacity = resource_capacity,
+                             reset = TRUE),
+                 "Because you set `reset = TRUE`, the")
 })
 
 test_that("setResource gives error", {
   expect_error(setResource(NS_params, resource_dynamics = "fake"),
                'The resource dynamics function "fake" is not defined.')
+})
+
+
+
+test_that("Can get and set resource_capacity slot", {
+  params <- NS_params
+  new <- 2 * resource_capacity(params)
+  comment(new) <- "test"
+  resource_capacity(params) <- new
+  expect_identical(resource_capacity(params), new)
+})
+test_that("Can get and set resource_rate slot", {
+  params <- NS_params
+  new <- 2 * resource_rate(params)
+  comment(new) <- "test"
+  resource_rate(params) <- new
+  expect_identical(resource_rate(params), new)
 })
\ No newline at end of file
